@@ -11,7 +11,6 @@ See L<MooseX::Templated::View>
 =cut
 
 use Moose;
-use MooseX::AttributeHelpers;
 
 use Template;
 use Carp;
@@ -86,15 +85,14 @@ This is the key/value stash that will be passed to the template engine
 =cut
 
 has 'stash' => (
-    'metaclass' => 'Collection::Hash',
+    'traits'    => [ 'Hash' ],
     'isa'       => 'HashRef',
     'is'        => 'rw',
-    'provides'  => {
-        'set'     => 'set_stash_key',
-        'get'     => 'get_stash_key',
-        'empty'   => 'empty_stash',
-        'delete'  => 'delete_stash_key',
-        'keys'    => 'stash_keys',
+    'handles'   => {
+        set_stash_key    => 'set',
+        get_stash_key    => 'get',
+        delete_stash_key => 'delete',
+        stash_keys       => 'keys',
     },
     'default' => sub { {} },
 );
@@ -110,8 +108,10 @@ sub process {
     my $self        = shift;
     my $tt_output   = '';
     my $src         = $self->get_source;
+    
     $self->engine->process( \$src, $self->stash, \$tt_output )
-        or croak( "couldn't process template: ".$self->error() );
+        or croak( "couldn't process template (module: ".( blessed $self->module ).")\n".
+                  "\t".$self->error() );
 
     return $tt_output;
 }
@@ -119,12 +119,10 @@ sub process {
 1; # Magic true value required at end of module
 __END__
 
-=head1 DESCRIPTION
-
-TODO
 
 =head1 DEPENDENCIES
 
+L<Template>
 
 =head1 INCOMPATIBILITIES
 
@@ -138,13 +136,14 @@ Please report any bugs or feature requests to
 C<bug-moosex-templated@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
+=head1 ACKNOWLEDGEMENTS
+
+Chris Prather (perigrin)
 
 =head1 AUTHOR
 
 Ian Sillitoe  C<< <isillitoe@cpan.org> >>
 
-Chris Prather C<< <perigrin@cpan.org> >>
-
 
 =head1 LICENCE AND COPYRIGHT
 
